@@ -2,9 +2,9 @@ use strict;
 use warnings;
 
 package Template::Transformer;
-{
-  $Template::Transformer::VERSION = '1.01';
-}
+$Template::Transformer::VERSION = '1.02';
+# ABSTRACT: Transformer used by Template::Resolver
+# PODNAME: Template::Transformer
 
 use Carp;
 use Data::Dumper;
@@ -130,11 +130,11 @@ __END__
 
 =head1 NAME
 
-Template::Transformer
+Template::Transformer - Transformer used by Template::Resolver
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
@@ -159,4 +159,6 @@ L<Template::Resolver|Template::Resolver>
 
 =back
 
+=for Pod::Coverage new transform
+
 =cut
